@@ -189,9 +189,10 @@ dRWRpipeline <- function(data, g, method=c("direct","indirect"), normalise=c("la
     ###### parallel computing
     flag_parallel <- F
     if(parallel==TRUE){
+    
         flag_parallel <- dCheckParallel(multicores=multicores, verbose=verbose)
         if(flag_parallel){
-            exp_b <- foreach(b=1:B, .inorder=T) %dopar% {
+            exp_b <- foreach::`%dopar%` (foreach::foreach(b=1:B, .inorder=T), {
                 progress_indicate(b, B, 10, flag=T)
                 if(permutation=="degree"){
                     seeds_random <- dp_randomisation(ig, P0matrix)
@@ -208,7 +209,7 @@ dRWRpipeline <- function(data, g, method=c("direct","indirect"), normalise=c("la
                     PTmatrix <- Matrix::Matrix(PTmatrix, sparse=T)
                 }
                 as.matrix(t(as.matrix(PT_random)) %*% PT_random)
-            }
+            })
         }
     }
     
