@@ -1,5 +1,7 @@
 # <span style="font-weight:bold; color:#F87217; text-decoration:underline">The dnet package is distributed as a CRAN package, freely available both for academic and non-academic users.</span> For it to be working, the latest R version should be first installed, along with several reguired/suggested packages. The dnet package, like other R packages, can run on Windows, Mac and Linux, but some functionalities (such as parallel computing) are only supported in Linux and Mac. Details on how to install are described in the <a href="http://supfam.org/dnet/install.html">Installation</a> page. Since the package is under active development, it is advisable to upgrade to the latest stable version by:
 
-install.packages("dnet",repos="http://cran.r-project.org",type="source")
+if(!("dnet" %in% rownames(installed.packages()))) remove.packages("dnet")
+install_github(c("dnet"), username="hfang-bristol")
+
 
 # <span style="font-weight:bold; color:#F87217; text-decoration:underline">The dnet package is specifically designed to analyse high-throughput omics data in an integrative manner.</span> It has the focus on making sense of these digitised data from different angles including: integration with molecular networks, enrichments using ontologies, and relevance to gene evolutionary ages. New functionalities will be noticed under the section 'Features' in the <a href="http://supfam.org/dnet">homepage</a>. The workflow of the package can also be found in the <a href="http://supfam.org/dnet/install.html">Installation</a> page.
